@@ -1,25 +1,21 @@
 # Author: Prabhu Ramachandran, Gael Varoquaux
-# Copyright (c) 2004-2024, Enthought, Inc.
+# Copyright (c) 2004-2021, Enthought, Inc.
 # License: BSD Style.
 """ A tool for easy and interactive visualization of data.
     Part of the Mayavi project of the Enthought Tool Suite.
 """
 
-__version__ = '4.8.3'
+__version__ = '4.7.4'
 
 __requires__ = [
     'apptools',
-    'configobj',
     'envisage',
     'numpy',
     'pyface>=6.1.1',
     'pygments',  # This is only needed for the Qt backend but we add it anyway.
     'traits>=6.0.0',
     'traitsui>=7.0.0',
-    'packaging',
-    'importlib_resources; python_version<"3.11"',
-    'vtk',
-    'puremagic'
+    'vtk'
 ]
 
 __extras_require__ = {
